# `acpkit` API

This page documents the public runtime helpers exported by the root package.

## Exceptions And Data Types

::: acpkit.AcpKitError

::: acpkit.CompatibilityManifest

::: acpkit.MissingAdapterError

::: acpkit.SurfaceOwner

::: acpkit.SurfaceStatus

::: acpkit.SurfaceSupport

::: acpkit.TargetResolutionError

::: acpkit.UnsupportedAgentError

::: acpkit.TargetRef

## Functions

::: acpkit.load_target

::: acpkit.run_target

::: acpkit.launch_target

::: acpkit.launch_command
